@@ -1,6 +1,5 @@
 """Module containing utility functionality for the parsing process."""
-from collections import Iterator
-from typing import Dict
+from typing import Dict, Iterator
 
 from pddl_plus_parser.models import PDDLType, SignatureType
 
@@ -19,4 +18,4 @@ def parse_signature(parameters: Iterator[str], domain_types: Dict[str, PDDLType]
         parameter_type = next(parameters)
         signature[parameter_name] = domain_types[parameter_type]
 
-    return signature
\ No newline at end of file
+    return signature
